@@ -1,10 +1,4 @@
 __all__ = (
-    # exceptions
-    "DirectoryNotFoundError",
-    "NotAFileError",
-    # types
-    "StrPath",
-    "StrPaths",
     # utils
     "prepend_path",
     "prepend_paths",
@@ -30,11 +24,8 @@ __all__ = (
     "get_files",
     "get_paths",
     "make_dirs",
-    # collections
-    "DataFolder",
 )
 
-from kaparoo.filesystem.collections import DataFolder
 from kaparoo.filesystem.directory import (
     dir_empty,
     dirs_empty,
@@ -43,10 +34,6 @@ from kaparoo.filesystem.directory import (
     get_paths,
     make_dirs,
 )
-from kaparoo.filesystem.exceptions import (
-    DirectoryNotFoundError,
-    NotAFileError,
-)
 from kaparoo.filesystem.existence import (
     dir_exists,
     dirs_exist,
@@ -61,7 +48,6 @@ from kaparoo.filesystem.existence import (
     path_exists,
     paths_exist,
 )
-from kaparoo.filesystem.types import StrPath, StrPaths
 from kaparoo.filesystem.utils import (
     prepend_path,
     prepend_paths,
